function result = rainLP(R,D)

% Laws and Parsons (LP) drop-size distribution, fitted by 
% de Wolf, Radio Sci. 36, 639 (2001), Equation (7)
% but with additional normalisation, s. Factor y.
% Input:
% R: Rain rate or line vector of rain rates, in mm/h 
% D: diameter or column vector of diameters, in mm
% C. Mtzler, Oct. 2002.

nsteps=length(D);
N0=1.98e-5*(D.^2.93)*R.^-0.384;
x1=log(R);
x2=x1.*x1;
y=1.047-0.0436*x1+0.00734*x2; % renorm. function 
yr=repmat(y,nsteps,1);
N0=N0.*yr;                    % renormalised N0 in 1/mm^4
LA=5.38./R.^0.186;
NLP=N0.*exp(-D*LA);           % renormalised LP Distribution 
%vfall=rainfallspeed(D);      % terminal fall speed
%volg=(pi/6)*D.^3;            % drop volume in mm^3, used
%y=volg.*vfall;               % for test of normalisation
%flux=3600000*dD*y'*NLP;      % volume flux = rain rate
%Nrenor=R./flux;              % renormalisation factor
%result=[log(R);R;Nrenor]';
result=NLP;