function result = rainMP(R, D)

% Marshall-Palmer (MP) drop-size distribution  
% with normalisation by Matzler
% Input:
% R: Rain rate or line vector of rain rates, in mm/h 
% D: diameter or column vector of diameters, in mm
% C. Mtzler, Oct. 2002.

nsteps=length(D);
N0=0.08/10000;                % original MP N0 in 1/mm^4
x1=log(R);
x2=x1.*x1;
y=0.842-0.00915*x1+0.0072*x2; % renorm. function 
yr=repmat(y,nsteps,1);
N0=N0.*yr;                    % Renormalised N0 in 1/mm^4
LA=4.1./R.^0.21;  
NMP=N0.*exp(-D*LA);           % Marshall-Palmer Distribution
%vfall=rainfallspeed(D);      % terminal fall speed
%volg=(pi/6)*D.^3;            % drop volume in mm^3, used
%y=volg.*vfall;               % for test of normalisation
%flux=3600000*dD*y'*NMP;      % volume flux = rain rate
%Nrenor=R./flux;              % renormalisation factor
%result=[log(R);R;Nrenor]';
result=NMP;