function result = raintestLPx2(nt,dD)

% Test of Laws and Parsons (LP) drop-size distribution 
% of de Wolf, Radio Sci. 36, 639 (2001), Equation (7)
% with additional renormalisation, s. Factor y.
% Test results to be plotted and returned.
% Input:
% nt: number of data pair (1, 2 or 3) to be selected
% dD incremental diameter for plot of distr. function, in mm
% C. Mtzler, Oct. 2002.
% Data from Burros and Attwood, 149, Table 23.2 in 
% M.I.Skolnik, Radar Handbook, 2nd Edition, 1990:
ba0=[0,28,50.1,18.2,3,.7;0 ,0.5,1.,1.5,2,2.5]; 
ba1=[0,10.9,37.1,31.3,13.5,4.9,1.5,0.6,0.2;0,0.5,1.,1.5,2,2.5,3,3.5,4];
ba2=[0,7.3,27.8,32.8,19,7.9,3.3,1.1,.6,.2;0,.5,1,1.5,2,2.5,3,3.5,4,4.5];
ba3=[0,2.6,11.5,24.5,25.4,17.3,10.1,4.3,2.3,1.2,0.6,0.2;
    0,0.5,1.,1.5,2,2.5,3,3.5,4,4.5,5,5.5];
ba4=[0,1.7,7.6,18.4,23.9,19.9,12.8,8.2,3.5,2.1,1.1,0.5,0.2;
    0,0.5,1.,1.5,2,2.5,3,3.5,4,4.5,5,5.5,6];
ba5=[0,1.2,5.4,12.5,19.9,20.9,15.6,10.9,6.7,3.3,1.8,1.1,0.5,0.2;
    0,0.5,1.,1.5,2,2.5,3,3.5,4,4.5,5,5.5,6,6.5];
ba6=[0,1,4.6,8.8,13.9,17.1,18.4,15,9,5.8,3,1.7,1,0.7;
    0,0.5,1.,1.5,2,2.5,3,3.5,4,4.5,5,5.5,6,6.5];
    a0=ba0'; R0=0.25;
    a1=ba1'; R1=1.25;
    a2=ba2'; R2=2.5;
    a3=ba3'; R3=12.5;
    a4=ba4'; R4=25;
    a5=ba5'; R5=50;
    a6=ba6'; R6=100;
if nt==1
    D0=a0(:,2); D1=a1(:,2); Ra=R0; Rb=R1; aa=a0; ab=a1;
elseif nt==2
    D0=a2(:,2); D1=a3(:,2); Ra=R2; Rb=R3; aa=a2; ab=a3;
elseif nt==3
    D0=a4(:,2); D1=a5(:,2); Ra=R4; Rb=R5; aa=a4; ab=a5;
end;
ns0=length(D0); ns1=length(D1);
Dmx=ceil(D1(ns1));      
NP0=rainLP(Ra,D0); NP1=rainLP(Rb,D1);
v0=sum(NP0)*0.5; v1=sum(NP1)*0.5;
aa=[50*NP0/v0,aa];ab=[50*NP1/v0,ab];
Dc=(0.0:dD:Dmx)';           % vector of quasi-continous D values
fLP0=rainLP(Ra,Dc);
fLP1=rainLP(Rb,Dc);         % quasi-continous LP function of de Wolf
D3=(pi/6)*(Dc.^3);          % sphere volume
df0=100*D3.*fLP0;
df1=100*D3.*fLP1;             % Percent contribution
fv0=dD*(pi/6)*(Dc.^3)'*fLP0; 
fv1=dD*(pi/6)*(Dc.^3)'*fLP1;  % volume fraction of rain water
f0=0.5*df0/fv0; f1=0.5*df1/fv1;               % Percent values for dD=0.5mm

subplot(1,2,1)
plot(Dc,f0,'r-',D0,aa(:,2),'bo--')
legend('LP','Burrows-Attwood')
title(sprintf('Delta-F, R=%gmm/h',Ra))
xlabel('D, mm')
subplot(1,2,2)
plot(Dc,f1,'r-',D1,ab(:,2),'bo--')
legend('LP','Burrows-Attwood')
title(sprintf('Delta-F, R=%gmm/h',Rb))
xlabel('D, mm')
